@@ -1458,10 +1458,9 @@ class Update(MethodsInterface):
         return True
 
     def delete_binhost(self):
-        if not self.clVars.GetBool('update.cl_update_binhost_set'):
+        if not self.clVars.GetBool('update.cl_update_binhost_set') or self.clVars.GetBool('cl_update_use_migration_host'):
             self.clVars.Write('cl_update_binhost', ' ', location="system")
             try:
-
                 bin_cache_fn = self.get_bin_cache_filename()
                 if path.exists(bin_cache_fn):
                     os.unlink(bin_cache_fn)
@@ -1482,6 +1481,8 @@ class Update(MethodsInterface):
                 self.clVars.Get("update.cl_update_portage_binhost_path"))
             if path.exists(binhost_fn):
                 os.unlink(binhost_fn)
+        if self.clVars.GetBool('cl_update_binhost_set') and self.clVars.GetBool('cl_update_use_migration_host'):
+            self.clVars.Write('cl_update_binhost', self.clVars.Get('cl_update_save_cur_binhost') , location="system")
         return False
 
     def update_binhost_list(self, dv=None):
@@ -1563,7 +1564,6 @@ class Update(MethodsInterface):
         quite_unlink(packages_ini)
         orig_ini = Binhosts.packages_check_ini(url_binhost.split("/grp")[0]).decode('utf-8')
         orig_packages = Binhosts.fetch_packages(url_binhost)
-
         try:
             with writeFile(packages_fn) as f:
                 pi = PackagesIndex(orig_packages)
@@ -1947,14 +1947,16 @@ class Update(MethodsInterface):
                     str(level)]]
         self.clVars.Set('update.cl_update_binhost_data',
             migr_binhost_data or Variable.EmptyTable, force=True)
+        self.clVars.Set('cl_update_binhost', migration_host.host)
         if not (migr_binhost_data):
             raise UpdateError(_("Failed to find working migration host with current level"))
         if not self.is_level_forced():
-            tag_cmp = self.cmp_rep_tag_to_current_calc_rep_tag()
+            #tag_cmp = self.cmp_rep_tag_to_current_calc_rep_tag()
+            tag_cmp = 2
             if tag_cmp <= 0:
                 self._update_increment_current_level()
-                self.set_migration_mode(False)
                 self.delete_binhost()
+                self.set_migration_mode(False)
                 raise RerunTrigger(_("Raising level due to migration host being outdated"))
         self.endTask()
         return True
@@ -2068,8 +2070,8 @@ class Update(MethodsInterface):
     def update_increment_current_level(self):
         self.startTask(_("Increasing local update level"))
         self._update_increment_current_level()
-        self.set_migration_mode(False)
         self.delete_binhost()
+        self.set_migration_mode(False)
         self.endTask()
         return True
 
@@ -2125,4 +2127,12 @@ class Update(MethodsInterface):
         else:
             val = val if val else 0
         self.clVars.Write(val_name, str(val), location="system")
-    
+
+    def check_if_migration(self):
+        """
+        Проверка для переключения на миграционный хост при ошибке валидации выбранного бинхоста
+        """
+        if self.clVars.GetBool("cl_update_use_migration_host"):
+            self.clVars.Set('cl_update_save_cur_binhost', self.clVars.Get('cl_update_binhost'))
+            return True
+        raise UpdateError(_("Something goes wrong while validating chosen binhost"))
