@@ -76,11 +76,15 @@ def get_synchronization_tasks(object_name):
              {'name': 'check_chosen_binhost',
               'message': _("Checking chosen binhost"),
               'method': Object('check_chosen_binhost(update.cl_update_binhost_choice)'),
+              'essential': False,
               'condition': lambda GetBool, Get: (
                   not GetBool('update.cl_update_binhost_recheck_set') and
                   Get('update.cl_update_binhost_choice') and
                   Get('update.cl_update_binhost_choice') != 'auto'),
               'depend': AllTasks.hasnot("check_current_binhost")},
+             {'name': 'failed_check_chosen_binhost',
+              'method': Object('check_if_migration()'),
+              'depend': AllTasks.failed_all("check_chosen_binhost")},
              {'name': 'group_find_binhost',
               'group': '',
               'while': (~AllTasks.has_any("detect_best_binhost") &
