@@ -1681,7 +1681,7 @@ class VariableClUpdateBinhostMigrationList(Variable):
     Список хостов с бинарными обновлениями для стабильной миграции
     """
     type = "list"
-    value = ["https://mirror.calculate-linux.org/migrate/"]
+    value = ["ftp://ftp.spb.calculate.ru/pub/calculate/migration/"]
 
 class VariableClUpdateBinhostBase(Variable):
     """
@@ -2008,11 +2008,6 @@ class VariableClUpdateUseMigrationHost(Variable):
     type = "bool"
     value = "off"
 
-# class VariableClUpdateMigrationHost(Variable):
-#     """
-#     Используемый хост миграции
-#     """
-#     value = ""
 
 class VariableClUpdateIgnoreLevel(Variable):
     """
@@ -2052,3 +2047,7 @@ class VariableClUpdateSavedTag(Variable):
     Сохраняемый тэг репозитория calculate
     """
     type = "int"
+
+
+class VariableClUpdateSaveCurBinhost(Variable):
+    value = " "
